# Torch Templates

- The file structure is vastly inspired from [madewithml.com](https://madewithml.com/) and many Kaggle Kernels from top kagglers.

- Till now, this would create a package for you with the `setup.py` and the `requirements.txt`.
- TODO:
    - Add TODO for hyperparameter tuning.

## File structure
```
- src
    - config
        - config.py
    - project_name
        - main.py
        - dataset.py
        - model.py
        - train.py
        - utils.py
        - hyparam.py (need to add...)
    - README.md
    - requirements.txt
```

## How to use?

### What are the functionalities?
![help](./images/help.png)

### Commands
![commands](./images/commands.png)

### Final Tree
![tree](./images/tree.png)
